#
# spec file for package ladspa-swh-plugins
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define tarname ladspa

Name:           ladspa-swh-plugins
Version:        0.4.17
Release:        lp152.3.5
Summary:        LADSPA SWH plugins
License:        GPL-2.0+
Group:          Productivity/Multimedia/Sound/Utilities
Url:            http://plugin.org.uk/
Source:         https://github.com/swh/ladspa/archive/v%{version}.tar.gz#/%{tarname}-%{version}.tar.gz
Source1:        ladspa-swh.tex
Source2:        ladspa-swh.pdf
Patch1:         swh-uninit-variable.diff
Patch2:         swh-readonly.dif
Patch3:         swh-0.4.13-gcc4-fix.diff
Patch5:         swh-libblo.dif
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fftw3-devel
BuildRequires:  gcc
BuildRequires:  ladspa-devel
BuildRequires:  libtool
BuildRequires:  perl-XML-Parser
BuildRequires:  pkgconfig
Supplements:    ladspa
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package provides a collection of LADSPA (Linux Audio Developer's
Simple Plug-in API) plugins written by Steve Harris.


%prep
%setup -q -n %{tarname}-%{version}
# This creates the .c files from .xml files.
for i in `ls -1 *.xml|cut -f 1 -d .` ;do ./makestub.pl "$i.xml" > "$i.c";done
%patch1
%patch2
%patch3
%patch5
cp gsm/README README-gsm
cp %{SOURCE1} .
cp %{SOURCE2} .

%build
# This replaces the wrong version with the right one in configure.ac
# see https://github.com/swh/ladspa/issues/41.
sed s/0.4.15/%{version}/ configure.ac>configure.ac1
mv configure.ac1 configure.ac

autoreconf -i -I m4
# This package failed when testing with -Wl,-as-needed being default.
# So we disable it here, if you want to retest, just delete this comment and the line below.
export SUSE_ASNEEDED=0
CFLAGS="%{optflags} -fPIC -ggdb -DPIC -fno-strict-aliasing" \
./configure --prefix=%{_prefix} \
              --disable-rpath \
              --enable-shared \
              --enable-dependency-tracking \
              --disable-static
make %{?_smp_mflags} CFLAGS="%{optflags} -fPIC -ggdb -DPIC -fno-strict-aliasing"
#
%install
make DESTDIR=%{buildroot} plugindir=%{_libdir}/ladspa install
%find_lang %{name} --all-name

%files -f %{name}.lang
%defattr(-,root,root)
%{_libdir}/ladspa
%{_datadir}/ladspa
%doc AUTHORS COPYING ChangeLog README TODO README-gsm
%doc ladspa-swh.tex
%doc ladspa-swh.pdf

%changelog
* Sat Nov 12 2016 davejplater@gmail.com
- Update to version 0.4.17, fixes boo#1006861
- Rebased swh-uninit-variable.diff, swh-readonly.dif,
  swh-0.4.13-gcc4-fix.diff and swh-libblo.dif.
- Added sed in spec file to place correct version in configure.ac
  see https://github.com/swh/ladspa/issues/41
- Upstream changes :
  Fixed GCC 5.3.1 warnings
  avoid global namespace symbol conflicts and possible double free
  NaN handling fix from Jaromír Mikeš
  Build reproducability fix from Jaromír Mikeš
  Spelling fixes from Jaromír Mikeš
  Don't use -march patch from Jaromír Mikeš
* Mon Mar 21 2016 davejplater@gmail.com
- Update to pre 0.4.16 git, version 0.4.15+git to fix undefined
  symbol errors in 14 plugins.
- Refreshed and rebased patches, removed swh-nostatic-lib.diff
- Upstream changes:
  Fix and improve build system
  Protect calls to "./makestub.pl *.xml > *.c"
  Fix "make distcheck" (i.e. shadow builds)
  po/: Remove generated files
  intl/: Resolve bundled libintl since AM_GNU_GETTEXT([external])
  is in place.
  configure.ac: Modernize call to AM_INIT_AUTOMAKE
  configure.ac: Add AC_CONFIG_MACRO_DIRS as proposed by libtoolize
  m4/: Remove copied files
  Fix compilation on Xcode 4.6
  Ignore "missing" file
  Renamed configure.in to configure.ac
  Issue https://github.com/swh/ladspa/issues/22
  Applied patch from gentoo swh-plugins-0.4.15-plugindir.patch
  Removed incorrecly checked-in "missing" file
  gcc5 does not support recursive inline functions
  Fix compilation on Xcode 4.6
  Made change to Makefile.am, as per issues/17#
  Use calloc instead of malloc when allocating port memory
  Fix memory leaks
  avoid global namespace symbol conflicts and possible double free
  Update bode_shifter_cv_1432.xml per #8
  Update surround_encoder_1401.xml per #8
  Update bode_shifter_1431.xml per #8
  Update surround_encoder_1401.xml per #8
  Update bode_shifter_cv_1432.xml per #8
  Fix off by one error in FIR application
* Mon Mar  3 2014 tiwai@suse.de
- Run spec-cleaner
- Remove obsoleted autoreq/autoprov tags
* Wed Feb 26 2014 tiwai@suse.de
- correct the license to GPL-2.0+
* Mon Dec 16 2013 tiwai@suse.de
- Initial version 0.4.15: split from ladspa package
- Patches carried from the original ladspa package:
  swh-uninit-variable.diff
  swh-readonly.dif
  swh-0.4.13-gcc4-fix.diff
  swh-nostatic-lib.diff
  swh-libblo.dif
